parse_and_exec_file

Function parse_and_exec_file 

pub fn parse_and_exec_file(
    ctx: &mut Context,
    source: &[u8],
    path: &str,
) -> Result<(), PsError>
Execute PostScript source loaded from a named file.

Like parse_and_exec, but records the file path on the StringSource entity so that resolve_filename can find the file’s parent directory when resolving relative paths in nested run/file calls.